@@ -1,7 +1,8 @@
 import unittest
 
-from . import CacheTestMixin, DecoratorTestMixin
-from cachetools import TTLCache, ttl_cache
+from cachetools import TTLCache
+
+from . import CacheTestMixin
 
 
 class Timer:
@@ -18,17 +19,72 @@ class Timer:
         self.time += 1
 
 
-class TTLCacheTest(unittest.TestCase, CacheTestMixin, DecoratorTestMixin):
+class TTLTestCache(TTLCache):
+    def __init__(self, maxsize, ttl=0, **kwargs):
+        TTLCache.__init__(self, maxsize, ttl=ttl, timer=Timer(), **kwargs)
 
-    def cache(self, maxsize, ttl=0, missing=None, getsizeof=None):
-        return TTLCache(maxsize, ttl, timer=Timer(), missing=missing,
-                        getsizeof=getsizeof)
 
-    def decorator(self, maxsize, ttl=0, typed=False, lock=None):
-        return ttl_cache(maxsize, ttl, timer=Timer(), typed=typed, lock=lock)
+class TTLCacheTest(unittest.TestCase, CacheTestMixin):
 
-    def test_lru(self):
-        cache = self.cache(maxsize=2)
+    Cache = TTLTestCache
+
+    def test_ttl(self):
+        cache = TTLCache(maxsize=2, ttl=1, timer=Timer())
+        self.assertEqual(0, cache.timer())
+        self.assertEqual(1, cache.ttl)
+
+        cache[1] = 1
+        self.assertEqual({1}, set(cache))
+        self.assertEqual(1, len(cache))
+        self.assertEqual(1, cache[1])
+
+        cache.timer.tick()
+        self.assertEqual({1}, set(cache))
+        self.assertEqual(1, len(cache))
+        self.assertEqual(1, cache[1])
+
+        cache[2] = 2
+        self.assertEqual({1, 2}, set(cache))
+        self.assertEqual(2, len(cache))
+        self.assertEqual(1, cache[1])
+        self.assertEqual(2, cache[2])
+
+        cache.timer.tick()
+        self.assertEqual({2}, set(cache))
+        self.assertEqual(1, len(cache))
+        self.assertNotIn(1, cache)
+        self.assertEqual(2, cache[2])
+
+        cache[3] = 3
+        self.assertEqual({2, 3}, set(cache))
+        self.assertEqual(2, len(cache))
+        self.assertNotIn(1, cache)
+        self.assertEqual(2, cache[2])
+        self.assertEqual(3, cache[3])
+
+        cache.timer.tick()
+        self.assertEqual({3}, set(cache))
+        self.assertEqual(1, len(cache))
+        self.assertNotIn(1, cache)
+        self.assertNotIn(2, cache)
+        self.assertEqual(3, cache[3])
+
+        cache.timer.tick()
+        self.assertEqual(set(), set(cache))
+        self.assertEqual(0, len(cache))
+        self.assertNotIn(1, cache)
+        self.assertNotIn(2, cache)
+        self.assertNotIn(3, cache)
+
+        with self.assertRaises(KeyError):
+            del cache[1]
+        with self.assertRaises(KeyError):
+            cache.pop(2)
+        with self.assertRaises(KeyError):
+            del cache[3]
+
+    def test_ttl_lru(self):
+        cache = TTLCache(maxsize=2, ttl=0, timer=Timer())
 
         cache[1] = 1
         cache[2] = 2
@@ -55,68 +111,8 @@ class TTLCacheTest(unittest.TestCase, CacheTestMixin, DecoratorTestMixin):
         self.assertEqual(cache[4], 4)
         self.assertEqual(cache[5], 5)
 
-    def test_ttl(self):
-        cache = self.cache(maxsize=2, ttl=1)
-        self.assertEqual(0, cache.timer())
-        self.assertEqual(1, cache.ttl)
-
-        cache[1] = 1
-        self.assertEqual({1}, set(cache))
-        self.assertEqual(1, len(cache))
-        self.assertEqual(1, cache.currsize)
-        self.assertEqual(1, cache[1])
-
-        cache.timer.tick()
-        self.assertEqual({1}, set(cache))
-        self.assertEqual(1, len(cache))
-        self.assertEqual(1, cache.currsize)
-        self.assertEqual(1, cache[1])
-
-        cache[2] = 2
-        self.assertEqual({1, 2}, set(cache))
-        self.assertEqual(2, len(cache))
-        self.assertEqual(2, cache.currsize)
-        self.assertEqual(1, cache[1])
-        self.assertEqual(2, cache[2])
-
-        cache.timer.tick()
-        self.assertEqual({2}, set(cache))
-        self.assertEqual(1, len(cache))
-        self.assertEqual(1, cache.currsize)
-        self.assertNotIn(1, cache)
-        self.assertEqual(2, cache[2])
-
-        cache[3] = 3
-        self.assertEqual({2, 3}, set(cache))
-        self.assertEqual(2, len(cache))
-        self.assertEqual(2, cache.currsize)
-        self.assertNotIn(1, cache)
-        self.assertEqual(2, cache[2])
-        self.assertEqual(3, cache[3])
-
-        cache.timer.tick()
-        self.assertEqual({3}, set(cache))
-        self.assertEqual(1, len(cache))
-        self.assertEqual(1, cache.currsize)
-        self.assertNotIn(1, cache)
-        self.assertNotIn(2, cache)
-        self.assertEqual(3, cache[3])
-
-        cache.timer.tick()
-        self.assertEqual(set(), set(cache))
-        self.assertEqual(0, len(cache))
-        self.assertEqual(0, cache.currsize)
-        self.assertNotIn(1, cache)
-        self.assertNotIn(2, cache)
-        self.assertNotIn(3, cache)
-
-        with self.assertRaises(KeyError):
-            del cache[1]
-        with self.assertRaises(KeyError):
-            cache.pop(2)
-
-    def test_expire(self):
-        cache = self.cache(maxsize=3, ttl=2)
+    def test_ttl_expire(self):
+        cache = TTLCache(maxsize=3, ttl=2, timer=Timer())
         with cache.timer as time:
             self.assertEqual(time, cache.timer())
         self.assertEqual(2, cache.ttl)
@@ -130,7 +126,6 @@ class TTLCacheTest(unittest.TestCase, CacheTestMixin, DecoratorTestMixin):
 
         self.assertEqual({1, 2, 3}, set(cache))
         self.assertEqual(3, len(cache))
-        self.assertEqual(3, cache.currsize)
         self.assertEqual(1, cache[1])
         self.assertEqual(2, cache[2])
         self.assertEqual(3, cache[3])
@@ -138,7 +133,6 @@ class TTLCacheTest(unittest.TestCase, CacheTestMixin, DecoratorTestMixin):
         cache.expire()
         self.assertEqual({1, 2, 3}, set(cache))
         self.assertEqual(3, len(cache))
-        self.assertEqual(3, cache.currsize)
         self.assertEqual(1, cache[1])
         self.assertEqual(2, cache[2])
         self.assertEqual(3, cache[3])
@@ -146,7 +140,6 @@ class TTLCacheTest(unittest.TestCase, CacheTestMixin, DecoratorTestMixin):
         cache.expire(3)
         self.assertEqual({2, 3}, set(cache))
         self.assertEqual(2, len(cache))
-        self.assertEqual(2, cache.currsize)
         self.assertNotIn(1, cache)
         self.assertEqual(2, cache[2])
         self.assertEqual(3, cache[3])
@@ -154,7 +147,6 @@ class TTLCacheTest(unittest.TestCase, CacheTestMixin, DecoratorTestMixin):
         cache.expire(4)
         self.assertEqual({3}, set(cache))
         self.assertEqual(1, len(cache))
-        self.assertEqual(1, cache.currsize)
         self.assertNotIn(1, cache)
         self.assertNotIn(2, cache)
         self.assertEqual(3, cache[3])
@@ -162,12 +154,11 @@ class TTLCacheTest(unittest.TestCase, CacheTestMixin, DecoratorTestMixin):
         cache.expire(5)
         self.assertEqual(set(), set(cache))
         self.assertEqual(0, len(cache))
-        self.assertEqual(0, cache.currsize)
         self.assertNotIn(1, cache)
         self.assertNotIn(2, cache)
         self.assertNotIn(3, cache)
 
-    def test_atomic(self):
+    def test_ttl_atomic(self):
         cache = TTLCache(maxsize=1, ttl=1, timer=Timer(auto=True))
         cache[1] = 1
         self.assertEqual(1, cache[1])
@@ -177,9 +168,12 @@ class TTLCacheTest(unittest.TestCase, CacheTestMixin, DecoratorTestMixin):
         self.assertEqual(1, cache.pop(1))
         cache[1] = 1
         self.assertEqual(1, cache.setdefault(1))
+        cache[1] = 1
+        cache.clear()
+        self.assertEqual(0, len(cache))
 
-    def test_tuple_key(self):
-        cache = self.cache(maxsize=1, ttl=0)
+    def test_ttl_tuple_key(self):
+        cache = TTLCache(maxsize=1, ttl=0, timer=Timer())
         self.assertEqual(0, cache.ttl)
 
         cache[(1, 2, 3)] = 42
